@@ -30,6 +30,17 @@ struct _GdaQuarkList {
 	GHashTable *hash_table;
 };
 
+GType gda_quark_list_get_type (void)
+{
+	static GType our_type = 0;
+
+	if (our_type == 0)
+		our_type = g_boxed_type_register_static ("GdaQuarkList",
+			(GBoxedCopyFunc) gda_quark_list_copy,
+			(GBoxedFreeFunc) gda_quark_list_free);
+	return our_type;
+}
+
 /*
  * Private functions
  */
@@ -41,8 +52,23 @@ free_hash_pair (gpointer key, gpointer value, gpointer user_data)
 	g_free (value);
 }
 
+static void
+copy_hash_pair (gpointer key, gpointer value, gpointer user_data)
+{
+	g_hash_table_insert ((GHashTable *) user_data,
+			     g_strdup ((const char *) key),
+			     g_strdup ((const char *) value));
+}
+
 /**
  * gda_quark_list_new
+ *
+ * Creates a new #GdaQuarkList, which is a set of key->value pairs,
+ * very similar to GLib's GHashTable, but with the only purpose to
+ * make easier the parsing and creation of data source connection
+ * strings.
+ *
+ * Returns: the newly created #GdaQuarkList.
  */
 GdaQuarkList *
 gda_quark_list_new (void)
@@ -57,6 +83,11 @@ gda_quark_list_new (void)
 
 /**
  * gda_quark_list_new_from_string
+ * @string: a connection string.
+ *
+ * Creates a new #GdaQuarkList given a connection string.
+ *
+ * Returns: the newly created #GdaQuarkList.
  */
 GdaQuarkList *
 gda_quark_list_new_from_string (const gchar *string)
@@ -69,24 +100,71 @@ gda_quark_list_new_from_string (const gchar *string)
 	return qlist;
 }
 
+/**
+ * gda_quark_list_clear
+ * @qlist: a #GdaQuarkList.
+ *
+ * Removes all strings in the given #GdaQuarkList.
+ */
+static void
+gda_quark_list_clear(GdaQuarkList *qlist)
+{
+	g_return_if_fail (qlist != NULL);
+	
+	g_hash_table_foreach_remove (qlist->hash_table,
+				     (GHRFunc) free_hash_pair,
+				     g_free);
+}
+
 /**
  * gda_quark_list_free
+ * @qlist: a #GdaQuarkList.
+ *
+ * Releases all memory occupied by the given #GdaQuarkList.
  */
 void
 gda_quark_list_free (GdaQuarkList *qlist)
 {
 	g_return_if_fail (qlist != NULL);
 
-	g_hash_table_foreach_remove (qlist->hash_table,
-				     (GHRFunc) free_hash_pair,
-				     g_free);
+	gda_quark_list_clear(qlist);
 	g_hash_table_destroy (qlist->hash_table);
 
 	g_free (qlist);
 }
 
+
+/**
+ * gda_quark_list_copy
+ * @qlist: quark_list to get a copy from.
+ *
+ * Creates a new #GdaQuarkList from an existing one.
+ * 
+ * Returns: a newly allocated #GdaQuarkList with a copy of the data in @qlist.
+ */
+GdaQuarkList *
+gda_quark_list_copy (GdaQuarkList *qlist)
+{
+	GdaQuarkList *new_qlist;
+
+	g_return_val_if_fail (qlist != NULL, NULL);
+	
+	new_qlist = gda_quark_list_new ();
+	g_hash_table_foreach (qlist->hash_table,
+			      copy_hash_pair,
+			      new_qlist->hash_table);
+	return new_qlist;
+}
+
 /**
  * gda_quark_list_add_from_string
+ * @qlist: a #GdaQuarkList.
+ * @string: a connection string.
+ * @cleanup: whether to cleanup the previous content or not.
+ *
+ * Adds new key->value pairs from the given @string. If @cleanup is
+ * set to %TRUE, the previous contents will be discarded before adding
+ * the new pairs.
  */
 void
 gda_quark_list_add_from_string (GdaQuarkList *qlist,
@@ -98,7 +176,8 @@ gda_quark_list_add_from_string (GdaQuarkList *qlist,
 	g_return_if_fail (qlist != NULL);
 	g_return_if_fail (string != NULL);
 
-	/* FIXME: remove all strings if cleanup != FALSE */
+	if (cleanup != FALSE)
+		gda_quark_list_clear(qlist);
 
 	arr = (gchar **) g_strsplit (string, ";", 0);
 	if (arr) {
@@ -124,6 +203,13 @@ gda_quark_list_add_from_string (GdaQuarkList *qlist,
 
 /**
  * gda_quark_list_find
+ * @qlist: a #GdaQuarkList.
+ * @name: the name of the value to search for.
+ *
+ * Searches for the value identified by @name in the given #GdaQuarkList.
+ *
+ * Returns: the value associated with the given key if found, or %NULL
+ * if not found.
  */
 const gchar *
 gda_quark_list_find (GdaQuarkList *qlist, const gchar *name)
@@ -142,7 +228,7 @@ gda_quark_list_find (GdaQuarkList *qlist, const gchar *name)
  * @qlist: a #GdaQuarkList structure.
  * @name: an entry name.
  *
- * Remove an entry from the #GdaQuarkList, given its name.
+ * Removes an entry from the #GdaQuarkList, given its name.
  */
 void
 gda_quark_list_remove (GdaQuarkList *qlist, const gchar *name)
