@@ -22,7 +22,6 @@
  */
 
 #if defined(HAVE_CONFIG_H)
-#  include <config.h>
 #endif
 
 #include <stdlib.h>
@@ -45,7 +44,6 @@ static gboolean gda_sqlite_provider_open_connection (GdaServerProvider *provider
 						     const gchar *password);
 static gboolean gda_sqlite_provider_close_connection (GdaServerProvider *provider,
 						      GdaConnection *cnc);
-
 static const gchar *gda_sqlite_provider_get_server_version (GdaServerProvider *provider,
 							    GdaConnection *cnc);
 static const gchar *gda_sqlite_provider_get_database (GdaServerProvider *provider,
@@ -200,29 +198,30 @@ gda_sqlite_provider_open_connection (GdaServerProvider *provider,
 			_("A full path must be specified on the "
 			  "connection string to open a database."));
 		return FALSE;
-	} else {
-		scnc = g_new0 (SQLITEcnc, 1);
-
-		scnc->connection = sqlite_open (t_filename, 0666, &errmsg);
-		scnc->file = g_strdup (t_filename);
-
-		if (!scnc->connection) {
-			gda_connection_add_error_string (cnc, errmsg);
-			
-			free (errmsg); /* must use free () for this pointer */
-			g_free (scnc->file);
-			g_free (scnc);
-			
-			return FALSE;
-		} else {
-
-			g_object_set_data (G_OBJECT (cnc),
-					   OBJECT_DATA_SQLITE_HANDLE,
-					   scnc);
-
-			return TRUE;
-		}
 	}
+
+	scnc = g_new0 (SQLITEcnc, 1);
+
+	scnc->connection = sqlite_open (t_filename, 0666, &errmsg);
+	scnc->file = g_strdup (t_filename);
+
+	if (!scnc->connection) {
+		gda_connection_add_error_string (cnc, errmsg);
+		
+		free (errmsg); /* must use free () for this pointer */
+		g_free (scnc->file);
+		g_free (scnc);
+			
+		return FALSE;
+	}
+
+	g_object_set_data (G_OBJECT (cnc), OBJECT_DATA_SQLITE_HANDLE, scnc);
+
+	/* set SQLite library options */
+	if (!gda_sqlite_provider_single_command (sqlite_prv, cnc, "PRAGMA empty_result_callbacks = ON"))
+		gda_connection_add_error_string (cnc, _("Could not set empty_result_callbacks SQLite option"));
+
+	return TRUE;
 }
 
 /* close_connection handler for the GdaSqliteProvider class */
@@ -276,7 +275,6 @@ process_sql_commands (GList *reclist, GdaConnection *cnc,
 			gint status, i;
 
 			sres = g_new0 (SQLITEresult, 1);
-			
 			status = sqlite_get_table (scnc->connection, arr[n],
 						   &sres->data,
 						   &sres->nrows,
@@ -468,6 +466,11 @@ gda_sqlite_provider_begin_transaction (GdaServerProvider *provider,
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (GDA_IS_TRANSACTION (xaction), FALSE);
 
+	if (gda_connection_get_options (cnc) & GDA_CONNECTION_OPTIONS_READ_ONLY) {
+		gda_connection_add_error_string (cnc, _("Transactions are not supported in read-only mode"));
+		return FALSE;
+	}
+
 	name = gda_transaction_get_name (xaction);
 	if (name)
 		sql = g_strdup_printf ("BEGIN TRANSACTION %s", name);
@@ -542,7 +545,7 @@ gda_sqlite_provider_single_command (const GdaSqliteProvider *provider,
 	gboolean result;
 	gint status;
 	gchar *errmsg = NULL;
-
+	
 	scnc = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_SQLITE_HANDLE);
 
 	if (!scnc) {
@@ -652,7 +655,7 @@ get_table_fields (GdaConnection *cnc, GdaParameterList *params)
 
 	for (i = 0; i < gda_data_model_get_n_columns (GDA_DATA_MODEL (reclist->data)); i++) {
 		GdaFieldAttributes *fa;
-		GList *value_list;
+		GList *value_list = NULL;
 
 		fa = gda_data_model_describe_column (GDA_DATA_MODEL (reclist->data), i);
 		if (!fa) {
@@ -663,7 +666,7 @@ get_table_fields (GdaConnection *cnc, GdaParameterList *params)
 		}
 
 		value_list = g_list_append (
-			NULL,
+			value_list,
 			gda_value_new_string (gda_field_attributes_get_name (fa)));
 		value_list = g_list_append (
 			value_list,
